package com.bweb.controller;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.utils.DateUtil;
import com.hfkj.common.utils.OrderUtil;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.entity.*;
import com.hfkj.model.ResponseData;
import com.hfkj.service.discount.CouponDiscountService;
import com.hfkj.service.goods.BsOrderGoodsService;
import com.hfkj.service.goods.GoodsMsgService;
import com.hfkj.service.goods.GoodsSpecsService;
import com.hfkj.service.hlt.HltCanteenService;
import com.hfkj.service.hlt.HuiLianTongUnionCardService;
import com.hfkj.service.order.BsOrderChildService;
import com.hfkj.sysenum.order.OrderLogisticsStatusEnum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;

@Controller
@RequestMapping(value="/test")
@Api(value="测试")
public class TestController {
    private static Logger log = LoggerFactory.getLogger(TestController.class);

    @Resource
    private GoodsMsgService goodsMsgService;

    @Resource
    private GoodsSpecsService goodsSpecsService;

    @Resource
    private CouponDiscountService couponDiscountService;

    @Resource
    private BsOrderChildService orderChildService;
    @Resource
    private BsOrderGoodsService orderGoodsService;
    @Resource
    private BsOrderGoodsService bsOrderGoodsService;

    @RequestMapping(value="/canteenConsume",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "食堂消费")
    public ResponseData canteenConsume(@RequestParam(value = "cardNo" , required = false) String cardNo,
                                      @RequestParam(value = "instCode" , required = false) String instCode,
                                      @RequestParam(value = "canteenId" , required = false) String canteenId) {
        try {

            String orderNo = OrderUtil.generateOrderNo();

            JSONObject cardInfo = HltCanteenService.canteenConsume(orderNo , cardNo , instCode , canteenId);
            if (StringUtils.isBlank(cardInfo.getString("data"))) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "请求失败");
            }
            return ResponseMsgUtil.success(HuiLianTongUnionCardService.resolveResponse(cardInfo.getString("data")));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/bindDiscountSpecs",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "根据类型绑定")
    public ResponseData bindDiscountSpecs(@RequestParam(value = "goodsType" , required = false) Integer goodsType ,
                                          @RequestParam(value = "discountId" , required = false) Long discountId) {
        try {

            Map<String , Object> map = new HashMap<>();
            map.put("goodsType" , goodsType);
            List<GoodsMsg> goodsMsg = goodsMsgService.getList(map);
            List<GoodsSpecs> specsList = goodsSpecsService.getList(map);

            List<CouponDiscountGoodsRel> goodsRelList = new ArrayList<>();
            for (GoodsMsg goods : goodsMsg) {
                List<GoodsSpecs> list = specsList.stream().filter(specs -> specs.getGoodsId().equals(goods.getId())).
                        collect(Collectors.toList());
                for (GoodsSpecs goodsSpecs : list) {
                    CouponDiscountGoodsRel goodsRel = new CouponDiscountGoodsRel();
                    goodsRel.setDiscountId(discountId);
                    goodsRel.setSpecsId(goodsSpecs.getId());
                    goodsRel.setCreateTime(new Date());
                    goodsRel.setStatus(1);
                    goodsRelList.add(goodsRel);

                }
            }
            couponDiscountService.insertGoodsRelBatch(goodsRelList);
            return ResponseMsgUtil.success("成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/orderGoodsUpdate",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "商品更新")
    public ResponseData orderGoodsUpdate() {
        try {


            List<BsOrderGoods> orderGoodsList = orderGoodsService.getList();

            for (BsOrderGoods goods : orderGoodsList) {
                BsOrderChild child = orderChildService.getDetail(goods.getChildOrderNo());
                goods.setStatus(child.getStatus());
                goods.setUpdateTime(new Date());
                orderGoodsService.update(goods);
            }

            return ResponseMsgUtil.success("成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/orderGoodsConfirmReceipt",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "商品确认收货")
    public ResponseData orderGoodsConfirmReceipt() {
        try {

            Map<String , Object> map = new HashMap<>();

            map.put("logisticsStatus" , "SIGN");
            map.put("status" , 2);

            List<BsOrderGoods> orderGoodsList = orderGoodsService.getList(map);

            for (BsOrderGoods goods : orderGoodsList) {

                // 判断时间是否是十天前

                if (DateUtil.differentDays(goods.getCreateTime() , new Date()) > 9) {
                    bsOrderGoodsService.confirmReceipt(goods.getId());
                    goods.setStatus(3);
                    goods.setUpdateTime(new Date());
                    orderGoodsService.update(goods);
                }
            }

            return ResponseMsgUtil.success("成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }


}
